@@ -1,9 +1,9 @@
 utils::globalVariables(c('CCAMLRp','Coast','Depth_cols','Depth_cuts','Depth_cols2','Depth_cuts2',
 'GridData','Labels','LineData','PointData','PolyData','SmallBathy','ID','PieData','PieData2',
-'Lat','Lon','N','Tot','p'))
+'Lat','Lon','N','Tot','p','Ass_Ar_Key'))
 #' 
 #' Loads and creates spatial data, including layers and tools that are relevant to CCAMLR activities.
-#' All operations use the Lambert azimuthal equal-area projection (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs).
+#' All operations use the Lambert azimuthal equal-area projection (via EPSG:6932).
 #'
 #' This package provides two broad categories of functions: load functions and create functions.
 #' 
@@ -33,29 +33,25 @@ utils::globalVariables(c('CCAMLRp','Coast','Depth_cols','Depth_cuts','Depth_cols
 #' }
 #' 
 #' @section Vignette:
-#' To learn more about CCAMLRGIS, start with the vignette:
-#' \code{browseVignettes(package = "CCAMLRGIS")}
+#' To learn more about CCAMLRGIS, start with the GitHub ReadMe (see \url{https://github.com/ccamlr/CCAMLRGIS#table-of-contents}).
 #' 
 #' @seealso 
 #' The CCAMLRGIS package relies on several other package which users may want to familiarize themselves with,
-#' namely \href{https://CRAN.R-project.org/package=sp}{sp},
-#' \href{https://CRAN.R-project.org/package=raster}{raster},
-#' \href{https://CRAN.R-project.org/package=rgeos}{rgeos} and
-#' \href{https://CRAN.R-project.org/package=rgdal}{rgdal}.
+#' namely sf (\url{https://CRAN.R-project.org/package=sf}) and 
+#' terra (\url{https://CRAN.R-project.org/package=terra}).
 #' 
 #'  
 #' @docType package
 #' @import sp
-#' @import rgdal
-#' @import rgeos
+#' @import sf
 #' @import geosphere
 #' @importFrom dplyr distinct group_by summarise_all left_join
 #' @importFrom grDevices colorRampPalette recordPlot replayPlot
-#' @importFrom graphics par rect segments text
-#' @importFrom methods slot
+#' @importFrom graphics par rect segments text lines abline legend
 #' @importFrom stats quantile median
 #' @importFrom utils read.csv setTxtProgressBar txtProgressBar edit menu download.file
 #' @importFrom magrittr %>%
-#' @importFrom raster raster extent extend crop extract rasterToContour pointDistance xres yres cut rasterToPolygons area crs match ncell setValues minValue maxValue mask cellStats contour click
+#' @importFrom terra rast crop ext mask vect classify expanse extract extend clamp as.polygons plot click
+#' @importFrom raster raster plot
 #' @name CCAMLRGIS
 NULL
\ No newline at end of file
